@@ -5,8 +5,10 @@ multiply2<-function(coeforig,pol){
   
   coef.result1<-rep(0,max(coeforig.d)+max(pol.d)+1)
   coef.result2<-coef.result1
-  coef.result1[coeforig.d+1]<-coeforig[coeforig.d+1]
-  coef.result2[coeforig.d+pol.d[2]+1]<-coeforig[coeforig.d+1]
+  coef.result1[coeforig.d+1]<-coeforig[coeforig.d+1]*pol[1]
+  if (length(pol.d)>1){
+  coef.result2[coeforig.d+pol.d[2]+1]<-coeforig[coeforig.d+1]*pol[pol.d[2] + 1]
+  }
   coef.result<-coef.result1+coef.result2
   
-  return(coef.result)}
\ No newline at end of file
+  return(coef.result)} 
